<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/revisions?lang_cible=tr
// ** ne pas modifier le fichier **

return [

	// D
	'diff_para_ajoute' => 'Eklenmiş paragraf ',
	'diff_para_deplace' => 'Yeri değiştirilmiş paragraf ',
	'diff_para_supprime' => 'Silinmiş paragraf ',
	'diff_texte_ajoute' => 'Eklenmiş metin ',
	'diff_texte_deplace' => 'Yeri değiştirilmiş metin ',
	'diff_texte_supprime' => 'Silinmiş metin ',

	// I
	'info_historique' => 'Gözden geçirmeler :',
	'info_historique_lien' => 'Değişikliklerin tarihçesini göster',
	'info_historique_titre' => 'Gözden geçirmeleri izle',

	// V
	'version_deplace_rubrique' => '<b>« @from@ »</b> den <b>« @to@ »</b> ye taşınmış.',
	'version_initiale' => 'İlk sürüm',
];
